Learn R Programming

kelvin (version 1.2-1)

Beir: Solutions to the Kelvin differential equations: 'Bei' and 'Ber'

Description

This function calculates the complex solution to the Kelvin differential equations using modified Bessel function of the first kind, specifically that which is produced by Bessel::BesselJ.

Usage

Beir(xseq, nu. = 0, return.list = FALSE, ...)

## S3 method for class 'default': Beir(xseq, nu. = 0, return.list = FALSE, ...)

Arguments

xseq
vector; values to evaluate the complex solution at
nu.
scalar; value of $\nu$ in $\mathcal{B}_\nu$
return.list
boolean; Should the result be a list instead of matrix?
...
arguments passed to Bessel::BesselJ

Value

  • If return.list==FALSE (default), a complex matrix with as many columns as using nSeq. creates. Otherwise the result is a list with matrices for Real and Imaginary components.

    NULL

References

http://mathworld.wolfram.com/KelvinFunctions.html

See Also

Ber, Bei, Keir

Examples

Run this code
Beir(1:10)    # defaults to nu.=0
Beir(1:10, nu.=2)

Run the code above in your browser using DataLab