Learn R Programming

kelvin (version 1.2-2)

Beir: Fundamental solution to the Kelvin differential equation: Bessel-J

Description

This function calculates the complex solution to the Kelvin differential equation using modified Bessel functions of the first kind, specifically those produced by Bessel::BesselJ.

Usage

Beir(xseq, nu. = 0, return.list = FALSE, ...)

## S3 method for class 'default': Beir(xseq, nu. = 0, return.list = FALSE, ...)

Bei(...)

Ber(...)

Arguments

xseq
vector; values to evaluate the complex solution at
nu.
scalar; value of $\nu$ in $\mathcal{B}_\nu$
return.list
boolean; Should the result be a list instead of matrix?
...
additional arguments. In Beir they are passed to Bessel::BesselJ, and in Ber, and Bei they are passed

Value

  • If return.list==FALSE (the default), a complex matrix with as many columns as using nSeq. creates. Otherwise the result is a list with matrices for Real and Imaginary components.

Details

Ber and Bei are wrapper functions which return the real and imaginary components, respectively.

References

http://mathworld.wolfram.com/KelvinFunctions.html

Imaginary: http://mathworld.wolfram.com/Bei.html

Real: http://mathworld.wolfram.com/Ber.html

See Also

kelvin-package

Other solutions: Kei, Keir, Keir.default, Ker

Examples

Run this code
Beir(1:10)    # defaults to nu.=0
Beir(1:10, nu.=2)
# Imaginary component only
Bei(1:10)
# Real component only
Ber(1:10)

Run the code above in your browser using DataLab