Learn R Programming

kelvin (version 2.0-2)

Beir: Fundamental solution to the Kelvin differential equation (J)

Description

This function calculates the complex solution to the Kelvin differential equation using modified Bessel functions of the first kind, specifically those produced by BesselJ.

Usage

Beir(x, ...)

# S3 method for default Beir(x, nu. = 0, nSeq. = 1, return.list = FALSE, ...)

Bei(...)

Ber(...)

Value

If return.list==FALSE (the default), a complex matrix with as many columns as using nSeq. creates. Otherwise the result is a list with matrices for Real and Imaginary components.

Arguments

x

numeric; values to evaluate the complex solution at

...

additional arguments passed to BesselK or Beir

nu.

numeric; value of \(\nu\) in \(\mathcal{B}_\nu\) solutions

nSeq.

positive integer; equivalent to nSeq in BesselJ

return.list

logical; Should the result be a list instead of matrix?

Author

Andrew Barbour

Details

Ber and Bei are wrapper functions which return the real and imaginary components of Beir, respectively.

References

http://mathworld.wolfram.com/KelvinFunctions.html

Imaginary: http://mathworld.wolfram.com/Bei.html

Real: http://mathworld.wolfram.com/Ber.html

See Also

kelvin-package, Keir, BesselJ

Examples

Run this code

Beir(1:10)    # defaults to nu.=0
Beir(1:10, nu.=2)
Beir(1:10, nSeq.=2)
Beir(1:10, nSeq.=2, return.list=TRUE)


# Imaginary component only
Bei(1:10)

# Real component only
Ber(1:10)

Run the code above in your browser using DataLab