Beir: Fundamental solution to the Kelvin differential equation (J)
Description
This function calculates the complex solution to the Kelvin differential
equation using modified Bessel functions of the first kind, specifically
those produced by BesselJ.
If return.list==FALSE (the default),
a complex matrix with as many columns as using nSeq. creates.
Otherwise the result is a list with matrices for
Real and Imaginary components.
Arguments
x
numeric; values to evaluate the complex solution at
...
additional arguments passed to BesselK or Beir
nu.
numeric; value of \(\nu\) in \(\mathcal{B}_\nu\) solutions
nSeq.
positive integer; equivalent to nSeq in BesselJ
return.list
logical; Should the result be a list instead of matrix?
Author
Andrew Barbour
Details
Ber and Bei are wrapper functions
which return the real and imaginary components of Beir, respectively.