Keir: Solutions to the Kelvin differential equations: 'Kei' and 'Ker'
Description
This function calculates the complex solution to the
Kelvin differential equations using modified Bessel
function of the second kind, specifically that which is
produced by Bessel::BesselK.
vector; values to evaluate the complex
solution at
nu.
scalar; value of $\nu$ in
$\mathcal{K}_\nu$
nSeq.
positive integer; if $nSeq > 1$,
computes the result for a sequence of values; if $\nu
>= 0: \nu, \nu+1, \cdots, \nu+nSeq-1$, if $\nu < 0:
\nu, \nu-1, \cdots, \nu-nSeq+1$.
add.tol
boolean; fudge factor to prevent an error
for zero-values
return.list
boolean; Should the result be a list
instead of matrix?
show.scaling
boolean; Should the normalization
values be given as a message?
...
additional parameters (currently unused)
Value
If return.list==FALSE (default), a complex matrix
with as many columns as using nSeq. creates.
Otherwise the result is a list with matrices for Real and
Imaginary components.