Learn R Programming

kelvin (version 2.0-2)

Keir: Complementary solution to the Kelvin differential equation (K)

Description

This function calculates the complex solution to the Kelvin differential equation using modified Bessel functions of the second kind, specifically those produced by BesselK.

Usage

Keir(x, ...)

# S3 method for default Keir( x, nu. = 0, nSeq. = 1, add.tol = TRUE, return.list = FALSE, show.scaling = FALSE, ... )

Kei(...)

Ker(...)

Value

If return.list==FALSE (the default), a complex matrix with as many columns as using nSeq. creates. Otherwise the result is a list with matrices for Real and Imaginary components.

Arguments

x

numeric; values to evaluate the complex solution at

...

additional arguments passed to BesselK or Keir

nu.

numeric; value of \(\nu\) in \(\mathcal{K}_\nu\) solutions

nSeq.

positive integer; equivalent to nSeq in BesselK

add.tol

logical; Should a fudge factor be added to prevent an error for zero-values?

return.list

logical; Should the result be a list instead of matrix?

show.scaling

logical; Should the normalization values be given as a message?

Author

Andrew Barbour

Details

Ker and Kei are wrapper functions which return the real and imaginary components of Keir,, respectively.

References

http://mathworld.wolfram.com/KelvinFunctions.html

Imaginary: http://mathworld.wolfram.com/Kei.html

Real: http://mathworld.wolfram.com/Ker.html

See Also

kelvin-package, Beir, BesselK

Examples

Run this code

Keir(1:10)    # defaults to nu.=0, nSeq=1
Keir(1:10, nu.=2)
Keir(1:10, nSeq=2)
Keir(1:10, nSeq=2, return.list=TRUE)


# Imaginary component only
Kei(1:10)

# Real component only
Ker(1:10)

Run the code above in your browser using DataLab