Keir: Complementary solution to the Kelvin differential equation (K)
Description
This function calculates the complex solution to the Kelvin differential
equation using modified Bessel functions of the second kind, specifically
those produced by BesselK.
If return.list==FALSE (the default),
a complex matrix with as many columns as using nSeq. creates.
Otherwise the result is a list with matrices for
Real and Imaginary components.
Arguments
x
numeric; values to evaluate the complex solution at
...
additional arguments passed to BesselK or Keir
nu.
numeric; value of \(\nu\) in \(\mathcal{K}_\nu\) solutions
nSeq.
positive integer; equivalent to nSeq in BesselK
add.tol
logical; Should a fudge factor be added to prevent an error for zero-values?
return.list
logical; Should the result be a list instead of matrix?
show.scaling
logical; Should the normalization values be given as a message?
Author
Andrew Barbour
Details
Ker and Kei are wrapper functions
which return the real and imaginary components of Keir,, respectively.