Learn R Programming

kelvin (version 2.0-2)

kelvin-package: Fundamental and equivalent solutions to the Kelvin differential equation using Bessel functions

Description

The functions here use Bessel functions to calculate the analytic solutions to the Kelvin differential equation, namely the fundamental (Be) and equivalent (Ke) complex functions.

Arguments

Author

Andrew Barbour <andy.barbour@gmail.com>

Details

The complex second-order ordinary differential equation, known as the Kelvin differential equation, is defined as $$x^2 \ddot{y} + x \dot{y} - \left(i x^2 + \nu^2\right) y = 0$$ and has a suite of complex solutions. One set of solutions, \(\mathcal{B}_\nu\), is defined in the following manner: $$\mathcal{B}_\nu \equiv \mathrm{Ber}_\nu (x) + i \mathrm{Bei}_\nu (x)$$ $$= J_\nu \left(x \cdot \exp(3 \pi i / 4)\right) $$ $$= \exp(\nu \pi i) \cdot J_\nu \left(x \cdot \exp(-\pi i / 4)\right)$$ $$= \exp(\nu \pi i / 2) \cdot I_\nu \left(x \cdot \exp(\pi i / 4)\right)$$ $$= \exp(3 \nu \pi i / 2) \cdot I_\nu \left(x \cdot \exp(-3 \pi i / 4)\right)$$ where \(J_\nu\) is a Bessel function of the first kind, and \(I_\nu\) is a modified Bessel function of the first kind.

Similarly, the complementary solutions, \(\mathcal{K}_\nu\), are defined as $$\mathcal{K}_\nu \equiv \mathrm{Ker}_\nu (x) + i \mathrm{Kei}_\nu (x)$$ $$= \exp(- \nu \pi i / 2) \cdot K_\nu \left(x \cdot \exp(\pi i / 4)\right)$$ where \(K_\nu\) is a modified Bessel function of the second kind.

The relationships between \(y\) in the differential equation, and the solutions \(\mathcal{B}_\nu\) and \(\mathcal{K}_\nu\) are as follows $$ y = \mathrm{Ber}_\nu (x) + i \mathrm{Bei}_\nu (x)$$ $$ = \mathrm{Ber}_{-\nu} (x) + i \mathrm{Bei}_{-\nu} (x)$$ $$ = \mathrm{Ker}_\nu (x) + i \mathrm{Kei}_\nu (x)$$ $$ = \mathrm{Ker}_{-\nu} (x) + i \mathrm{Kei}_{-\nu} (x)$$

In the case where \(\nu=0\), the differential equation reduces to $$x^2 \ddot{y} + x \dot{y} - i x^2y = 0$$ which has the set of solutions: $$ J_0 \left(i \sqrt{i} \cdot x\right)$$ $$ = J_0 \left(\sqrt{2} \cdot (i-1) \cdot x / 2\right)$$ $$ = \mathrm{Ber}_0 (x) + i \mathrm{Bei}_0 (x) \equiv \mathcal{B}_0$$

This package has functions to calculate \(\mathcal{B}_\nu\) and \(\mathcal{K}_\nu\).

References

Abramowitz, M. and Stegun, I. A. (Eds.). "Kelvin Functions." \(\S 9.9\) in Handbook of Mathematical Functions with Formulas, Graphs, and Mathematical Tables, 9th printing. New York: Dover, pp. 379-381, 1972.

Kelvin functions: http://mathworld.wolfram.com/KelvinFunctions.html

Bessel functions: http://mathworld.wolfram.com/BesselFunction.html

See Also

Fundamental solution: Beir

Equivalent solution: Keir